@@ -6,7 +6,7 @@ This file is part of minos framework.
 Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
 """
 
-from .abstract import (
+from .abc import (
     MinosStorage,
 )
 from .lmdb import (
